/**
 * Color Library Lite 1.0 - A library for converting colors between RGB, HSV, HSL, and HCY color spaces.
 *
 * Written by Zandario
 */

/// HSV counterpart to rgb(), this takes the values you input and converts them to a color string.
#define hsv(H, S, V, A...) rgb(h=H, s=S, v=V, A=A, space=COLORSPACE_HSV)
/// HSL counterpart to rgb(), this takes the values you input and converts them to a color string.
#define hsl(H, S, L, A...) rgb(h=H, s=S, l=L, A=A, space=COLORSPACE_HSL)
/// HCY counterpart to rgb(), this takes the values you input and converts them to a color string.
#define hcy(H, C, Y, A...) rgb(h=H, c=C, y=Y, A=A, space=COLORSPACE_HCY)

/// HSV counterpart to rgb2num(), this takes the values you input and converts them to a list of colors.
#define hsv2num(H, S, V, A...) rgb2num(hsv(H, S, V, A), COLORSPACE_HSV)
/// HSL counterpart to rgb2num(), this takes the values you input and converts them to a list of colors.
#define hsl2num(H, S, L, A...) rgb2num(hsl(H, S, L, A), COLORSPACE_HSL)
/// HCY counterpart to rgb2num(), this takes the values you input and converts them to a list of colors.
#define hcy2num(H, C, Y, A...) rgb2num(hcy(H, C, Y, A), COLORSPACE_HCY)

// Converting Color to a list of channel values.
#define color2rgb(HEX) (rgb2num(HEX, COLORSPACE_RGB)) // COLORSPACE_RGB is irrelevent but there for consistency.
#define color2hsv(HEX) (rgb2num(HEX, COLORSPACE_HSV))
#define color2shl(HEX) (rgb2num(HEX, COLORSPACE_HSL))
#define color2hcy(HEX) (rgb2num(HEX, COLORSPACE_HCY))
